@@ -4,10 +4,7 @@ from . import multiprocessing
 from .utils import CSRTopo
 from .utils import Topo as p2pCliqueTopo
 from .utils import init_p2p
+
 __all__ = [
-    "Feature",
-    "GraphSageSampler",
-    "CSRTopo",
-    "p2pCliqueTopo",
-    "init_p2p"
-]
\ No newline at end of file
+    "Feature", "GraphSageSampler", "CSRTopo", "p2pCliqueTopo", "init_p2p"
+]
